from django import forms

from tapeforms.contrib.bootstrap import BootstrapTapeformMixin


class CustomTapeformMixin(BootstrapTapeformMixin):
    """
    Mixin pour produire des formulaires intégrés avec Bootstrap.

    Il étends le mixin fournis avec `tapeforms` afin d'utiliser les classes
    personnalisées (custom forms) pour les champs de type checkbox et select.
    """

    widget_template_overrides = {
        forms.FileInput: 'forms/widgets/file_input.html',
        forms.ClearableFileInput: 'forms/widgets/clearable_file_input.html',
    }

    #: Template à étendre pour la disposition du formulaire.
    base_layout_template = BootstrapTapeformMixin.layout_template

    def get_field_container_css_class(self, bound_field):
        if isinstance(bound_field.field.widget, forms.CheckboxInput):
            return 'form-group custom-control custom-checkbox'

        return super().get_field_container_css_class(bound_field)

    def get_field_label_css_class(self, bound_field):
        if isinstance(bound_field.field.widget, forms.CheckboxInput):
            return 'custom-control-label'

        return super().get_field_label_css_class(bound_field)

    def apply_widget_options(self, field_name):
        super().apply_widget_options(field_name)

        widget = self.fields[field_name].widget

        if isinstance(widget, forms.DateInput):
            # Force ISO format which is expected by the browser's date picker
            # for the input value, due to the use of the "date" type.
            widget.format = '%Y-%m-%d'

    def get_widget_css_class(self, field_name, field):
        if isinstance(field.widget, forms.Select):
            return 'custom-select'

        if isinstance(field.widget, forms.CheckboxInput):
            return 'custom-control-input'

        if isinstance(field.widget, forms.FileInput):
            return 'custom-file-input'

        return super().get_widget_css_class(field_name, field)
