import django_tables2 as tables
import pytest

from ..tables import ActionsColumn


class TestActionsColumn:
    def test_required_action_url(self):
        with pytest.raises(ValueError):
            ActionsColumn()

    def test_overwrite_template(self):
        column = ActionsColumn(update_url='some-url')
        assert column.template_code is None
        assert column.template_name == 'tables/actions_column.html'

        column = ActionsColumn(update_url='some-url', template_name='foo.html')
        assert column.template_code is None
        assert column.template_name == 'foo.html'

        column = ActionsColumn(update_url='some-url', template_code='foo')
        assert column.template_code == 'foo'
        assert column.template_name is None

    def test_resolve_url(self):
        record = 'foo'
        column = ActionsColumn(update_url='some-url')

        with pytest.raises(ValueError):
            column.resolve_url_for_record(('some-url', (1,)), record)

        assert column.resolve_url_for_record(None, record) is None
        assert column.resolve_url_for_record('/update/', record) == '/update/'
        assert column.resolve_url_for_record(lambda r: r, record) == 'foo'

    def test_render(self):
        class TestTable(tables.Table):
            actions = ActionsColumn(
                update_url='/update/', delete_url='/delete/'
            )
            update = ActionsColumn(update_url='/update/')
            delete = ActionsColumn(delete_url='/delete/')

        table = TestTable({'foo': 'bar'})
        actions_cell = table.rows[0].get_cell('actions')
        assert 'href="/update/" class="update-link' in actions_cell
        assert 'href="/delete/" class="delete-link' in actions_cell
        update_cell = table.rows[0].get_cell('update')
        assert 'href="/update/" class="update-link' in update_cell
        assert 'delete-link' not in update_cell
        delete_cell = table.rows[0].get_cell('delete')
        assert 'update-link' not in delete_cell
        assert 'href="/delete/" class="delete-link' in delete_cell
